---

Name: dondacalculator

Version: 0.0.1

Description: dondacalculator is a Python package made for performing essential math calculations for everyday use.

Supported Actions:

- Addition
- Multiplication
- Subtraction
- Division
- nth root calculation
- Memory reset
- Print out memory

---
How to install this package:
1. installing via terminal -

pip install dondacalculator

2. installing via IDE -

%pip install dondacalculator

---
How it works:

from calculator import Calculator as calc

new_obj = calc.Calculator()  # New object is created.

new_obj.add(15) # Returns 15.0

new_obj.subtract(5) # Returns 10.0

new_obj.multiply(20) # Returns 200.0

new_obj.divide(2) # Returns 100.0

new_obj.n_root(2) # Returns 10.0

new_obj.return_memory # Returns 10.0

new_obj.memory_reset # Resets memory to 0.0

---

Keywords: calculator, addition, multiplication, subtraction, division, nth root

This project is licensed under the terms of the MIT license.